@@ -3,6 +3,22 @@ from loguru import logger
 import requests
 
 
+def get_up_token(cjdg_access_token):
+    """
+    七牛上传令牌
+    """
+    url = "http://bms.chaojidaogou.com/shopguide/api/file/qiniu/getUpToken"
+    params = {
+        "accessToken": cjdg_access_token
+    }
+    response = requests.get(url, params=params)
+    if response.status_code == 200:
+        return response.json()
+    params["response"] = response
+    params["response_raw"] = response.content
+    logger.error(params)
+
+
 def request_accesstoken(acc: str, pwd: str) -> str:
     # 请求accesstooke函数
     url = "http://bms.microc.cn/shopguide/api/auth/logon"
